#' Plot different analysis
#' 
#' @details 
#' 
#' `analyse_graphics()` consists in a call to `plot_uncertainty()`, 
#' `plot_sobol()`, and `plot_explore()` in a more less systematic way. All the
#' calls are made with a `device` fixed to the same value, which allows to
#' easily save graphicals outputs either in pdf or png.
#' 
#' * for `plot_uncertainty()`, views `npv` and `benefit` are plotted
#' * for `plot_sobol()`, views `S` (first-order Sobol indices), and `T`(total
#' order Sobol indices) are plotted
#' * for `plot_explore()`, views `S` (first-order Sobol indices), and `T`(total
#' order Sobol indices) are plotted
#' 
#' @param input list of input data.
#' @param analysis list of results from `analyse_uncertainty`.
#' @param uncertainty logical, should uncertainty graph be plotted.
#' @param sensitivity logical, should sobol graph be plotted.
#' @param exploration logical, should exploration graph be plotted.
#' @param device character, define how the graphics are saved.
#' 
#' @return Nothing.
#' 
#' @export
#'  
#' @encoding UTF-8
#' @author Frédéric Grelot, \email{frederic.grelot.1994_cran@m4x.org} 

analyze_graphic = function(
    input,
    analysis,
    uncertainty = TRUE,
    sensitivity = TRUE,
    exploration = FALSE,
    device = "pdf"
) {
    if (isTRUE(uncertainty)) {
        plot_uncertainty(input, analysis[["u_a"]], "npv", device)
        plot_uncertainty(input, analysis[["u_a"]], "benefit", device)
    }
	if (isTRUE(sensitivity)) {
        plot_sobol(input, analysis[["s_a"]], "S", device)
        plot_sobol(input, analysis[["s_a"]], "T", device)
    }
	if (isTRUE(exploration)) {
        plot_explore(input, analysis[["s_a"]], analysis[["u_a"]], device)
    }
}
