#' Estimate nominal result of input.
#' 
#' @param input list of input data.
#' @param verbose logical, should the function be verbose.
#' 
#' @return Matrix of nominal values of inputs, and corresping estimation for
#' indicators computed in `model_npv`.
#' 
#' @export
#'  
#' @encoding UTF-8
#' @author Frédéric Grelot, \email{frederic.grelot.1994_cran@m4x.org} 

calculate_nominal = function(
    input,
    verbose = getOption("floodam.cba.sa")[["verbose"]]
) {
	period = input[["flood"]][["period_nominal"]]
	cost =  input[["cost"]][colnames(input[["calendar"]])[-1] , "nominal"]
	hydraulic = input[["flood"]][["hydraulic_nominal"]]
	impact = t(t(input[["impact"]][, rownames(input[["flood"]])]) * hydraulic)
	impact_base = set_impact_base(input)

	result = t(c(cost, period, hydraulic, rep(1, nrow(input[["impact"]]))))
	colnames(result) = c(
		paste("cost", rownames(input[["cost"]]), sep = "_"),
		paste("period", rownames(input[["flood"]]), sep = "_"),
		paste("hydraulic", rownames(input[["flood"]]), sep = "_"),
		paste("impact", rownames(input[["impact"]]), sep = "_"))

	result = model_npv(
        result,
        impact_base,
        input[["calendar"]],
        rate = getOption("floodam.cba.sa")[["rate"]],
        indicator = "complete"
    )
	
	msg = sprintf(
        "\t- Model EAD: %s\n\t- Model NPV: %s",
        signif(result[, "benefit"], 4),
        signif(result[, "npv"], 4)
    )
	write(msg, file = input[["path_log"]], append = TRUE)
	if (isTRUE(verbose)) message(gsub("\t- ", "", msg))
	
	invisible(result)	
}

