#' Draw all parameters needed for model_npv
#' 
#' @param input list of input data.
#' @param base data.frame, base values of parameters.
#' 
#' @return data.frame with n+1 lines of all parameters
#' 
#' @export
#'  
#' @encoding UTF-8
#' @author Frédéric Grelot, \email{frederic.grelot.1994_cran@m4x.org} 

draw_all_parameter = function(input, base) {
    flood = input[["flood"]]
    cost = input[["cost"]]
    impact = input[["impact"]]
    n = input[["n"]]
    if (missing(base)) base = calculate_nominal(input, verbose = FALSE)

	period = draw_parameter(flood[, grep("period", colnames(flood))], n)
	cost = draw_parameter(cost, n)
	hydraulic = draw_parameter(flood[, grep("hydraulic", colnames(flood))], n)
	impact = draw_parameter(cbind(1, impact[c("min", "max", "type")]), n)

    result = cbind(cost, period, hydraulic, impact)
    colnames(result) = colnames(base)[seq(1, ncol(result))]
    result = rbind(base[seq(1, ncol(result))], result)
    return(result)
}
