#' Draw parameters
#' 
#' @param x vector
#' @param n integer, number of draws
#' @param type character, how results are sent back
#'
#' @return matrix or list of parameters, depending on type
#' 
#' @export draw_all_parameter
#'  
#' @encoding UTF-8
#' @author Frédéric Grelot, \email{frederic.grelot.1994_cran@m4x.org} 

draw_parameter = function(x, n, type = "matrix") {

	draw_parameter_vector = function(x, n) {
		mi = as.numeric(x[2])
		ma = as.numeric(x[3])
		if(x[4] == "relative") {
			no = as.numeric(x[1])
			mi = no * (1 + mi)
			ma = no * (1 + ma)
		}
		mi + (ma - mi) * stats::runif(n)
	}
	
	if(is.vector(x)) {
		return(draw_parameter_vector(x, n))
	}
	
	result = apply(x, 1, draw_parameter_vector, n)
	if(type == "matrix")
		return(result)
	if(type == "list") 
		return(invisible(as.list(as.data.frame(t(result)))))
	stop("Bad type for return")
}
