#' Estimate indicators.
#' 
#' @param x matrix, key parameters for npv calculation.
#' @param impact_base matrix, base impacts from wich variations will be done.
#' @param calendar data.frame, calendar of the project.
#' @param indicator character, define what sort of inputs will be returned.
#' @param ... parameters that will be passed to `discount_weight()``.
#' 
#' @return Matrix of nominal values of inputs, and corresping estimation for
#' indicators computed in `model_npv`.
#' 
#' @export
#'  
#' @encoding UTF-8
#' @author Frédéric Grelot, \email{frederic.grelot.1994_cran@m4x.org} 


model_npv = function(
    x,
    impact_base,
    calendar,
	indicator = c("complete", "npv", "benefit"),
    ...
) {
    indicator = match.arg(indicator)

	cost = grep("^cost", colnames(x))
	impact = grep("^impact", colnames(x))
	period = grep("^period", colnames(x))
	hydraulic = grep("^hydraulic", colnames(x))
	
	n = length(impact_base) / length(period)
	
	impact = t(
        apply(
            x[, c(impact, hydraulic), drop = FALSE],
            1, 
		    fit_impact,
            b = impact_base,
            i = length(impact)
        )
    )
	weight = t(
        apply(
            apply(x[, period, drop = FALSE], 1, calculate_weight),
            2,
            rep,
            n
        )
    )
	benefit = apply(impact * weight, 1, sum)
	npv = apply(
        cbind(benefit, -x[, cost, drop = FALSE]),
        1,
        discount, 
        calendar,
        discount_weight(as.numeric(rownames(calendar)), ...)
    )
	
	if (indicator == "complete") {
		colnames(impact) = names(impact_base)
		result = cbind(x, impact, benefit, npv)
	}
	if (indicator == "npv") {
		result = npv
	}
	if (indicator == "benefit") {
		result = benefit
	}
	
	invisible(result)
}
