#' Plot exploration analysis
#' 
#' @details 
#' 
#' To be specified.
#' 
#' @param input list of input data.
#' @param analysis list of results from `analyse_uncertainty()`.
#' @param view character, define which type of indices should be plotted.
#' @param device character, define how the graphics are saved.
#' 
#' @return Nothing.
#' 
#' @export
#'  
#' @encoding UTF-8
#' @author Frédéric Grelot, \email{frederic.grelot.1994_cran@m4x.org}

plot_explore = function(
    input,
    analysis,
    view = c("1D", "2D", "2Dbis"),
    device = c("none", "pdf", "png")
) {
    device = match.arg(device)
    view = match.arg(view)

    if (device != "pdf"){
        msg = c(
            sprintf("'%s' device not yet inplemented for plot_expore.", device),"Nothing is plotted."
        )
        warning(sprintf("%s ", msg))
        return(NULL)
    }
    if (any(!c("s_a", "u_a") %in% names(analysis))) {
        warning("No admissible view in analysis. Nothing is plotted.")
        return(NULL)
    }
    
    u_a = analysis[["u_a"]]
    s_a = analysis[["s_a"]]

	selection = rownames(s_a[s_a[["original"]] > .1,])
	
	if (length(selection) == 0) return(NULL)
	neg = sum(u_a[, "NPV"] <= 0) / nrow(u_a)
	
	color = rep(grDevices::gray(0.9), nrow(u_a))
	color[u_a[, "NPV"] < 0] = "red"
	cex = rep(1, nrow(u_a))
	cex[u_a[, "NPV"] < 0] = 3

	grDevices::pdf(
        file.path(input[["path_output"]], "plot_exploration_1D.pdf")
    )
	for(n in selection) {
		p = prop_negative(u_a[ ,n], u_a[ ,"NPV"], 100)
		graphics::barplot(
            p,
            main = n,
            col = "red",
            names.arg = names(p),
            ylim = c(0, 1)
        )
		graphics::abline(h = neg)
	}
	grDevices::dev.off()
	
	if (length(selection) == 1) return(NULL)
	eg = expand.grid(selection, selection)
	eg = eg[eg[1] != eg[2],]

	grDevices::pdf(file.path(input[["path_output"]], "plot_exploration_2D.pdf"))
	apply(eg, 1, plot_compare, y = u_a, color = color, cex = cex)
	grDevices::dev.off()

	grDevices::pdf(
        file.path(input[["path_output"]], "plot_exploration_2Dbis.pdf")
    )
	for (i in seq(nrow(eg))) {
		p = prop_negative(u_a[, as.character(unlist(eg[i,]))], u_a[ ,"NPV"], 20)
		graphics::image(
            as.numeric(dimnames(p)[[1]]),
            as.numeric(dimnames(p)[[2]]),
            p, 
			xlab = names(dimnames(p))[1],
            ylab = names(dimnames(p))[2],
			breaks = seq(0, 1, length.out = 101),
            col = grDevices::gray(seq(1, 0, length.out = 100)))
	}
	grDevices::dev.off()
}
