#' Plot sobol analysis
#' 
#' @details 
#' 
#' `analysis` can be either list of all `data.frame` resulting from
#' sensitivity analysis, or the list containing this list as returned by
#' `analyse_uncertainty()`
#' 
#' @param input list of input data.
#' @param analysis list of results from `analyse_uncertainty()`. See details.
#' @param view character, define which type of indices should be plotted.
#' @param device character, define how the graphics are saved.
#' 
#' @return Nothing.
#' 
#' @export
#'  
#' @encoding UTF-8
#' @author Frédéric Grelot, \email{frederic.grelot.1994_cran@m4x.org} 

plot_sobol = function(
    input,
    analysis,
    view = c("S", "T"),
    device = c("none", "pdf", "png")
) {
    device = match.arg(device)
    view = match.arg(view)

    if ("s_a" %in% names(analysis)) {
        s_a = analysis[["s_a"]][[view]]
    } else {
        s_a = analysis[[view]]
    }
    if (is.null(s_a)) {
        warning("No admissible view in analysis. Nothing is plotted")
        return(NULL)
    }

    path_plot = file.path(
        input[["path_output"]],
        sprintf("plot_sobol_%s.pdf", view)
    )

    if (device == "pdf") {
        grDevices::cairo_pdf(path_plot)
        on.exit(grDevices::dev.off())
    }
    if (device == "png") {
        grDevices::png(path_plot)
        on.exit(grDevices::dev.off())
    }

    title_text = switch(
        view,
        "S" = "Sobol first-order indices",
        "T" = "Sobol total sensitivity indices",
    )

    cost = nrow(input[["cost"]])
    flood = nrow(input[["flood"]])
    impact = nrow(input[["impact"]])

	old_par = graphics::par(mar = c(5, 10, 2, 2) + 1)
	color = c(
		rep("green", cost), rep("orange", flood),
		rep("blue", flood), rep("red", impact))
	
	o = order(s_a[["original"]])
	s = s_a[o, ]
	color = color[o]
	xlim = if(max(s[["original"]] > .49)) c(0, 1) else c(0, .5)

	graphics::barplot(
        s[["original"]],
        names.arg = rownames(s),
        horiz = TRUE,
        las = 1,
        col = color,
		xlim = xlim
    )
	graphics::title(main = title_text)
    graphics::par(old_par)
}
