#' Plot uncertainty analysis
#' 
#' @details 
#' 
#' `analysis` can be either the data.frame of all results from uncertainty
#' analysis, or the list containing this data.frame as returned by
#' `analyse_uncertainty()`
#' 
#' @param input list of input data.
#' @param analysis list of results from `analyse_uncertainty()`. See details.
#' @param view character, define which type of indices should be plotted.
#' @param device character, define how the graphics are saved.
#' 
#' @return Nothing.
#' 
#' @export
#'  
#' @encoding UTF-8
#' @author Frédéric Grelot, \email{frederic.grelot.1994_cran@m4x.org} 

plot_uncertainty = function(
    input,
    analysis,
    view = c("npv", "benefit"),
    device = c("none", "pdf", "png")
) {
    view = match.arg(view)
    device = match.arg(device)

    if ("u_a" %in% names(analysis)) {
        u_a = analysis[["u_a"]]
    } else {
        u_a = analysis
    }
    if (is.null(u_a)) {
        warning("No admissible view in analysis. Nothing is plotted")
        return(NULL)
    }

    path_plot = file.path(
        input[["path_output"]],
        sprintf("plot_hist_%s.%s", view, device)
    )

    if (device == "pdf") {
        grDevices::cairo_pdf(path_plot)
        on.exit(grDevices::dev.off())
    }
    if (device == "png") {
        grDevices::png(path_plot)
        on.exit(grDevices::dev.off())
    }

	neg = sum(u_a[, view] <= 0) / nrow(u_a)
	nominal = u_a[1, view]
	
	histo = graphics::hist(u_a[, view], breaks = 100, plot = FALSE)
	color =  ifelse(histo[["breaks"]] <= 0, "red", "white")

	plot(histo, col = color, xlab = view, main = NULL)
	graphics::title(main = sprintf("Histogram of %s\n", view))
    if (view == "npv"){
        graphics::title(
            main = sprintf("\n(Part of negative values: %s)", round(neg, 2)),
            cex.main = .8
        )
    }
	graphics::segments(
        nominal,
        0,
        nominal,
        round(max(histo[["counts"]])),
        col = "blue",
        lwd = 1.5
    )
	graphics::text(
        nominal,
        max(histo$counts) * 1.02,
        sprintf("Nominal: %s", signif(nominal,3)),
        col = "blue"
    )
}
