% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/load_data.R
\encoding{UTF-8}
\name{load_data}
\alias{load_data}
\title{Load all data necessary to perform analysis}
\usage{
load_data(
  case,
  path_input,
  path_output = getOption("floodam.cba.sa")[["path_output"]],
  n = 1000,
  type_input = getOption("floodam.cba.sa")[["type_input"]],
  rate = getOption("floodam.cba.sa")[["rate"]],
  check = getOption("floodam.cba.sa")[["check"]],
  verbose = getOption("floodam.cba.sa")[["verbose"]]
)
}
\arguments{
\item{case}{character, name of the case study.}

\item{path_input}{character, path where to find input data.}

\item{path_output}{character, path where to save output data.}

\item{n}{integer, path where to save output data.}

\item{type_input}{character, format of input.}

\item{rate}{character, parameter to choose discount rate.}

\item{check}{logical, should input data be checked.}

\item{verbose}{logical, should the function be verbose.}
}
\value{
list of all input data and useful paths.
}
\description{
Load all data necessary to perform analysis
}
\details{
\code{load_data()} loads all data necessary to perform analysis. It defines also
some key parameters such as where to save outputs, how many draws should be
done for uncertainty analysis, what should be the discount rate.

\code{load_data()} can also make some checks on the format of inputs, to ensure
that everything will work fine when applying analysis. If some checks are
not passed, a message is given to help correct problems.
}
\examples{

case = "test"
path_input = system.file("extdata", package = "floodam.cba.sa")

# minimum information given
input = load_data(case, path_input)

# without any message
input = load_data(case, path_input, verbose = FALSE)

# readjusting
input = load_data(case, path_input, n = 100)

}
\author{
Frédéric Grelot, \email{frederic.grelot.1994_cran@m4x.org}
}
