% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read_input.R
\encoding{UTF-8}
\name{read_input}
\alias{read_input}
\title{Read input from a directory from different possible formats}
\usage{
read_input(path_input, type_input = c("csv2", "csv1", "ods", "xlsx"))
}
\arguments{
\item{path_input}{character, path where to find input data.}

\item{type_input}{character, format of input data. See details.}
}
\value{
Named list of data.frame of input data found in \code{path_input}.
}
\description{
Read input from a directory from different possible formats
}
\details{
\code{read_input()} loads all data from a given type in a directory. It does not
perform any check on the integrity of the data.

\code{type_input} controls the way data is imported:
\describe{
\item{csv2}{use data.table::fread with dec = "," on all "csv" files
found in path_input. So sep is guessed.}
\item{csv1}{use data.table::fread without sepcification on all "csv"
files found in path_input.. So sep is guessed.}
\item{ods}{use readODS::read_ods on all sheets of the "ods" file found
in path_input.}
\item{xlsx}{use readxl::read_xlsx on all sheets of the "xlsx" file
found in path_input.}
}
}
\examples{

path_input = system.file("extdata", "test", package = "floodam.cba.sa")

# Default to csv2
input_default = read_input(path_input)
input_csv2 = read_input(path_input, "csv2")
identical(input_default, input_csv2)

# ods format
input_ods = read_input(path_input, "ods")
# May not be TRUE because of numeric / integer format
identical(input_default, input_ods)
all.equal(input_default, input_ods, check.attributes = FALSE)

# xlsx format
input_xlsx = read_input(path_input, "xlsx")
# May not be TRUE because of numeric / integer format
identical(input_default, input_xlsx)
all.equal(input_default, input_xlsx, check.attributes = FALSE)

}
\author{
Frédéric Grelot, \email{frederic.grelot.1994_cran@m4x.org}
}
